@@ -7,21 +7,19 @@
 #' @usage rootSize(mat.list, pixelA, diameter.classes = c(1, 2, 2.5, 10),
 #' class.names = diameter.classes,
 #' thickness = 0.625,
-#' airHU = -850.3233,
-#' airSD = 77.6953,
-#' waterHU = 63.912,
-#' waterSD = 14.1728,
+#' means     = c(-850.3233, 63.912, 271.7827, 1345.0696),
+#' sds       = c(77.6953, 14.1728, 39.2814, 45.4129), 
+#' densities = c(0.0012, 1, 1.23, 2.2),
 #' pixel.minimum = 4)
 #' 
 #' @param mat.list list of DICOM images for a sediment core (values in Hounsfield Units)
 #' @param pixelA pixel area (mm2)
 #' @param diameter.classes an integer vector of diameter cut points. Units are mm (zero is added in automatically).
 #' @param class.names not used presently
-#' @param thickness CT image thickness (mm)
-#' @param airHU mean value for air-filled calibration rod (all rod arguments are in Hounsfield Units)
-#' @param airSD standard deviation for air-filled calibration rod
-#' @param waterHU mean value for water-filled calibration rod
-#' @param waterSD standard deviation for water-filled calibration rod
+#' @param thickness slice thickness for computed tomography image series (mm)
+#' @param means mean values (units = Hounsfield Units) for calibration rods used.
+#' @param sds standard deviations (units = Hounsfield Units) for calibration rods used. Must be in the same order as \code{means}.
+#' @param densities numeric vector of known cal rod densities. Must be in the same order as \code{means} and \code{sds}.
 #' @param pixel.minimum minimum number of pixels needed for a clump to be identified as a root
 #' 
 #' @return value \code{rootSize} returns a dataframe with one row per CT slice. Values returned are the number, volume (cm3), and surface area (cm2) of particles in each size class with an upper bound defined in \code{diameter.classes}.
@@ -57,6 +55,7 @@
 #' @importFrom utils txtProgressBar
 #' @importFrom oro.dicom extractHeader
 #' @importFrom oro.dicom readDICOM
+#' @importFrom stats predict
 #' 
 #' @export
 
@@ -64,34 +63,63 @@ rootSize <- function (mat.list, pixelA,
                       diameter.classes = c(1, 2, 2.5, 10), # mm, targets clumps less than or equal to "diameter" argument
                       class.names = diameter.classes,
                       thickness = 0.625, # mm
-                      airHU = -850.3233, # Hounsfield Units
-                      airSD = 77.6953,
-                      waterHU = 63.912,
-                      waterSD = 14.1728,
+                      means     = c(-850.3233, 63.912, 271.7827, 1345.0696),  # all cal rod units are in Hounsfield Units
+                      sds       = c(77.6953, 14.1728, 39.2814, 45.4129),  # in same order as means. units are in Hounsfield Units
+                      densities = c(0.0012, 1, 1.23, 2.2),
                       pixel.minimum = 4) {
   # function creates dataframe with root/rhizome numbers and perimeter(!) for each depth interval
   pb <- utils::txtProgressBar(min = 0, max = length(mat.list), initial = 0, style = 3)
+  
+  ##### section added 20190922 to separate calibration curve from component partitioning
+  densitydf <- data.frame(HU = means, density = densities)
+  summary(lm1 <- stats::lm(density ~ HU, data = densitydf)) # density in g/cm3
+  if (summary(lm1)$r.squared < 0.95) { # print message to console if r2 < 0.95 
+    message(cat("\n Note: Calibration curve has limited explanatory power; r2 = ", round(summary(lm1)$r.squared, 3), "\n"))
+  }
+  densToHU <- stats::lm(HU ~ density, data = densitydf)
+  
+  partition.means <- stats::predict(densToHU, newdata = data.frame(density = c(0.0012, 1, 1.23, 2.2))) # this is hard-coded to reflect partitioning in Davey et al. 2011
+  
+  air.proxy   <- which.min(abs(means - partition.means[1])) # which element to use for air SD?
+  water.proxy <- which.min(abs(means - partition.means[2])) # which element to use for water SD?
+  Si.proxy    <- which.min(abs(means - partition.means[3])) # which element to use for Si SD?
+  glass.proxy <- which.min(abs(means - partition.means[4])) # which element to use for glass SD?
+  
+  partition.sds   <- c(sds[c(air.proxy, water.proxy, Si.proxy, glass.proxy)])
+  
+  ### now, set means and SDs used for partitioning
+  airHU      <- partition.means[1]
+  airSD      <- partition.sds[1]
+  waterHU    <- partition.means[2]
+  waterSD    <- partition.sds[2]
+  SiHU       <- partition.means[3]
+  SiSD       <- partition.sds[3]
+  glassHU    <- partition.means[4]
+  glassSD    <- partition.sds[4]
+  ##### end section added 20190922
+  
+  
   voxelVol <- pixelA * thickness / 1e3 # cm3
-  air.UB   <- airHU + airSD # lower bound on R&R, exclusive. earl adds 1 to this quantity to start next category
+  air.UB <- airHU + airSD # lower bound on R&R, exclusive. earl adds 1 to this quantity to start next category
   water.LB <- waterHU - waterSD # upper bound on R&R, inclusive
   # clump IDs extracted on basis of area
   # with rule: clumps must be greater than 1 pixel
   # this rule is based on comparison of ImageJ and R results
-  diams    <- c(0, diameter.classes) # revise diameter classes to include zero
+  diams <- c(0, diameter.classes) # revise diameter classes to include zero
   thresh.A <- pi*(diams/2)^2 # convert diameter to area
-  thresh.pixels    <- round(thresh.A / pixelA)  # convert area to no of pixels (irregular clumps are included; should maybe use floor() instead of round())
+  thresh.pixels <- round(thresh.A / pixelA)  # convert area to no of pixels (irregular clumps are included; should maybe use floor() instead of round())
   thresh.pixels[1] <- pixel.minimum
   
   for (i in 1:length(mat.list)) {
     depth <- thickness * i / 10 # cm
-    temp  <- mat.list[[i]]
+    temp <- mat.list[[i]]
     
     ### adjust here to get size class mass estimates
     temp[(temp > air.UB) & (temp <= water.LB)] <- 1 # isolate pixels with R&R density, change to 1
     temp[!temp == 1] <- NA # make sure only two values exist: 1, NA
     if(length(temp) == 0) next 
     
-    if (length(!is.na(temp)) > 0) {
+    if (sum(!is.na(temp)) > 0) {
       rmat <- raster::raster(temp)
       rmat.int <- raster::clump(rmat, directions = 8, gaps = FALSE)
       clump.sub1 <- data.frame(freq(rmat.int))
@@ -129,10 +157,10 @@ rootSize <- function (mat.list, pixelA,
           outDatInt2 <- cbind(outDatInt2, outDatInt)
         }
       }
-    } else if (length(!is.na(temp)) == 0) { # fill in zeroes if there aren't any clumps
+    } else if (sum(!is.na(temp)) == 0) { # fill in zeroes if there aren't any clumps
       for (j in 2:length(diams)) {
         outDatInt <- data.frame(particles = 0, surfArea = 0) #,surfaceVol = 0)
-        names(outDatInt) <- paste0(names(outDatInt2), ".", diams[j - 1], "_", diams[j], "mm")
+        names(outDatInt) <- paste0(names(outDatInt), ".", diams[j - 1], "_", diams[j], "mm")
         if (j == 2) {
           outDatInt2 <- outDatInt 
         } else {
